#[allow(clippy::all)]
#[allow(unused_variables)]
#[allow(unused_imports)]
#[allow(dead_code)]
mod cornucopia;
#[allow(clippy::all)]
#[allow(unused_variables)]
#[allow(unused_imports)]
#[allow(dead_code)]
mod test;
